==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-quicklaunch/translations/quicklaunch_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="229"/>
        <source>Drop Error</source>
        <translation>Fehler beim fallen lassen</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="230"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Datei/URL &apos;%1&apos; kann momentan nicht in die Schnellstartleiste eingebettet werden</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="336"/>
        <source>Drop application
icons here</source>
        <translation>Anwendungsymbol
hier fallen lassen</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Nach links verschieben</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Nach rechts verschieben</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="64"/>
        <source>Remove from quicklaunch</source>
        <translation>Aus der Schnellstartleiste entfernen</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-quicklaunch/translations/quicklaunch_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="229"/>
        <source>Drop Error</source>
        <translation>Fehler beim Ablegen</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="230"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Datei/URL &apos;%1&apos; kann momentan nicht in die Schnellstartleiste eingebettet werden</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="336"/>
        <source>Drop application
icons here</source>
        <translation>Anwendungsymbole
hierhin ziehen</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Nach links verschieben</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Nach rechts verschieben</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Aus der Schnellstartleiste entfernen</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
</context>
</TS>
